@@ -1,6 +1,6 @@
 /*
  * Normaliz
- * Copyright (C) 2007-2021  W. Bruns, B. Ichim, Ch. Soeger, U. v. d. Ohe
+ * Copyright (C) 2007-2022  W. Bruns, B. Ichim, Ch. Soeger, U. v. d. Ohe
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -12,7 +12,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * As an exception, when this program is distributed through (i) the App Store
  * by Apple Inc.; (ii) the Mac App Store by Apple Inc.; or (iii) Google Play
@@ -29,6 +29,7 @@
 #include <string>
 #include <climits>
 #include <cmath>
+#include <iosfwd>
 
 #include <libnormaliz/general.h>
 
@@ -39,8 +40,16 @@
 //---------------------------------------------------------------------------
 
 namespace libnormaliz {
-using namespace std;
 
+using std::cerr;
+using std::endl;
+using std::istream;
+using std::ostream;
+using std::ostringstream;
+using std::string;
+using std::stringstream;
+using std::vector;
+using std::ws;
 
 //---------------------------------------------------------------------------
 //                     Basic functions
@@ -98,6 +107,7 @@ inline bool try_convert(mpz_class& ret, const long& val) {
     ret = val;
     return true;
 }
+
 bool try_convert(mpz_class& ret, const long long& val);
 
 bool try_convert(nmz_float& ret, const long& val);
@@ -133,6 +143,16 @@ inline bool try_convert(nmz_float& ret, const nmz_float& val) {
     return true;
 }
 
+inline bool try_convert(mpq_class& ret, const mpz_class& val) {
+    ret = val;
+    return true;
+}
+
+inline bool try_convert(mpq_class& ret, const long& val) {
+    ret = val;
+    return true;
+}
+
 bool fits_long_range(long long a);
 
 //--------------------------------------------------------------------
@@ -189,7 +209,7 @@ inline bool using_renf<renf_elem_class>() {
 //--------------------------------------------------------------------
 
 // for the interpretation of a string as a decimal fraction or floating point number
-mpq_class dec_fraction_to_mpq(string s);
+mpq_class dec_fraction_to_mpq(std::string s);
 
 //--------------------------------------------------------------------
 
@@ -213,28 +233,28 @@ inline bool is_scalar_zero<nmz_float>(const nmz_float& m){
 
 template <typename Integer>
 inline bool check_range(const Integer& m) {
-    const Integer max_primary = int_max_value_primary<Integer>();
+    static Integer max_primary = int_max_value_primary<Integer>();
     return (Iabs(m) <= max_primary);
 }
 
 template <>
-inline bool check_range<mpz_class>(const mpz_class& m) {
+inline bool check_range<mpz_class>(const mpz_class&) {
     return true;
 }
 
 template <>
-inline bool check_range<nmz_float>(const nmz_float& m) {
+inline bool check_range<nmz_float>(const nmz_float&) {
     return true;
 }
 
 template <>
-inline bool check_range<mpq_class>(const mpq_class& m) {
+inline bool check_range<mpq_class>(const mpq_class&) {
     return true;
 }
 
 #ifdef ENFNORMALIZ
 template <>
-inline bool check_range<renf_elem_class>(const renf_elem_class& m) {
+inline bool check_range<renf_elem_class>(const renf_elem_class&) {
     return true;
 }
 #endif
@@ -386,148 +406,6 @@ size_t decimal_length(Integer a);
 template <typename Integer>
 mpz_class nmz_factorial(Integer n);
 
-//---------------------------------------------------------------------------
-//                     Input
-//---------------------------------------------------------------------------
-
-inline mpq_class mpq_read(istream& in) {
-    const string numeric = "+-0123456789/.e";
-    in >> std::ws;
-    string s;
-    char c;
-    bool is_float = false;
-    while (in.good()) {
-        c = in.peek();
-        size_t pos = numeric.find(c);
-        if (pos == string::npos)
-            break;
-        if (pos > 12)
-            is_float = true;
-        in >> c;
-        s += c;
-    }
-
-    if (s == "") {
-        string t;
-        t += c;
-        throw BadInputException("Empty number string preceding character " + t +
-                                ". Most likely mismatch of amb_space and matrix format or forgotten keyword.");
-    }
-
-    // cout << "t " << s << " f " << is_float << endl;
-
-    if (s[0] == '+')
-        s = s.substr(1);  // must suppress + sign for mpq_class
-
-    try {
-        if (!is_float) {
-            return mpq_class(s);
-        }
-        else
-            return dec_fraction_to_mpq(s);
-    } catch (const std::exception& e) {
-        cerr << e.what() << endl;
-        throw BadInputException("Illegal number string " + s + " in input, Exiting.");
-    }
-}
-
-// To be used in input.cpp
-inline void string2coeff(mpq_class& coeff, istream& in, const string& s) {  // in here superfluous parameter
-    
-    stringstream sin(s);
-    coeff = mpq_read(sin);
-    // coeff=mpq_class(s);
-}
-
-// To be used from other sources
-inline void string2coeff(mpq_class& coeff, const string& s) {
-    
-    // cout << "SSSSSS " << s << endl;
-    
-    const string numeric = "+-0123456789/.e "; // must allow blank
-    for(auto& c: s){
-        size_t pos = numeric.find(c);
-        if(pos == string::npos)
-            throw BadInputException("Illegal character in numerical string");
-    }
-    
-    
-    stringstream sin(s);
-    coeff = mpq_read(sin);
-    // coeff=mpq_class(s);
-}
-
-inline void read_number(istream& in, mpq_class& number) {
-    number = mpq_read(in);
-}
-
-inline void read_number(istream& in, long& number) {
-    in >> number;
-}
-
-inline void read_number(istream& in, long long& number) {
-    in >> number;
-}
-
-inline void read_number(istream& in, nmz_float& number) {
-    in >> number;
-}
-
-inline void read_number(istream& in, mpz_class& number) {
-    in >> number;
-}
-
-#ifdef ENFNORMALIZ
-
-inline void string2coeff(renf_elem_class& coeff, istream& in, const string& s) {  // we need in to access the renf
-
-    try {
-        renf_class* K = (renf_class*)in.pword(renf_class::xalloc());
-        coeff = renf_elem_class(*K, s);
-    } catch (const std::exception& e) {
-        cerr << e.what() << endl;
-        throw BadInputException("Illegal number string " + s + " in input, Exiting.");
-    }
-}
-
-inline void read_number(istream& in, renf_elem_class& number) {
-    // in >> number;
-
-    char c;
-
-    in >> ws;
-    c = in.peek();
-    if (c != '(' && c != '\'' && c != '\"') {  // rational number
-        mpq_class rat = mpq_read(in);
-        number = renf_elem_class(rat);
-        return;
-    }
-
-    // now we have a proper field contains
-
-    in >> c;  // read (
-
-    string num_string;
-    bool skip = false;
-    while (in.good()) {
-        c = in.peek();
-        if (c == ')' || c == '\'' || c == '\"') {
-            in >> c;
-            break;
-        }
-        if (c == '~' || c == '=' || c == '[')  // skip the approximation
-            skip = true;
-        in.get(c);
-        if (in.fail())
-            throw BadInputException("Error in reading number: field element not terminated");
-        if (!skip)
-            num_string += c;
-    }
-    string2coeff(number, in, num_string);
-}
-#endif
-
-// formerly conver.h
 // conversion for integers, throws ArithmeticException if conversion fails
 template <typename ToType, typename FromType>
 inline void convert(ToType& ret, const FromType& val) {
@@ -553,28 +431,22 @@ ToType convertTo(const FromType& val) {
     return copy;
 }
 
-
-inline bool try_convert(mpz_class& ret, const mpq_class& val) {
-    assert(false);  // must never be used
-    return false;
-}
-
-inline bool try_convert(mpq_class& ret, const mpz_class& val) {
+inline bool try_convert(mpz_class& ret, const mpq_class&) {
     assert(false);  // must never be used
     return false;
 }
 
 #ifdef ENFNORMALIZ
-inline  bool try_convert(renf_elem_class& ret, const mpz_class& val) {
+inline bool try_convert(renf_elem_class& ret, const mpz_class& val) {
     ret = val;
     return true;
 }
 
-inline  bool try_convert(mpz_class& ret, const renf_elem_class& val) {
+inline bool try_convert(mpz_class& ret, const renf_elem_class& val) {
     renf_elem_class help = val;
     if (!help.is_integer())
         throw ArithmeticException("field element cannot be converted to integer");
-    ret = help.get_num();
+    ret = help.num();
     return true;
 }
 
@@ -601,13 +473,13 @@ inline bool try_convert(long& ret, const renf_elem_class& val) {
 }
 
 inline bool try_convert(mpq_class& ret, const renf_elem_class& val) {
-    nmz_float ret_double = val.get_d();
+    nmz_float ret_double = static_cast<double>(val);
     ret = mpq_class(ret_double);
     return true;
 }
 
 inline bool try_convert(nmz_float& ret, const renf_elem_class& val) {
-    ret = val.get_d();
+    ret = static_cast<double>(val);
     return true;
 }
 #endif
@@ -729,7 +601,7 @@ inline nmz_float gcd(const nmz_float& a, const nmz_float& b) {
 }
 
 template <>
-inline  mpz_class gcd(const mpz_class& a, const mpz_class& b) {
+inline mpz_class gcd(const mpz_class& a, const mpz_class& b) {
     mpz_class g;
     mpz_gcd(g.get_mpz_t(), a.get_mpz_t(), b.get_mpz_t());
     return g;
@@ -737,7 +609,7 @@ inline  mpz_class gcd(const mpz_class& a, const mpz_class& b) {
 
 #ifdef ENFNORMALIZ
 template <>
-inline  renf_elem_class gcd(const renf_elem_class& a, const renf_elem_class& b) {
+inline renf_elem_class gcd(const renf_elem_class& a, const renf_elem_class& b) {
     if (a == 0 && b == 0)
         return 0;
     return 1;
@@ -756,7 +628,7 @@ Integer lcm(const Integer& a, const Integer& b) {
 }
 
 template <>
-inline  mpz_class lcm<mpz_class>(const mpz_class& a, const mpz_class& b) {
+inline mpz_class lcm<mpz_class>(const mpz_class& a, const mpz_class& b) {
     mpz_class g;
     mpz_lcm(g.get_mpz_t(), a.get_mpz_t(), b.get_mpz_t());
     return g;
@@ -782,7 +654,7 @@ Integer int_max_value_dual() {
 // bool int_max_value_dual_long_computed = false;
 
 template <>
-inline  long int_max_value_dual() {
+inline long int_max_value_dual() {
     static long max_value;
 
     if (int_max_value_dual_long_computed)
@@ -800,7 +672,7 @@ inline  long int_max_value_dual() {
 // bool int_max_value_dual_long_long_computed = false;
 
 template <>
-inline  long long int_max_value_dual() {
+inline long long int_max_value_dual() {
     static long long max_value;
 
     if (int_max_value_dual_long_long_computed)
@@ -818,7 +690,7 @@ inline  long long int_max_value_dual() {
 //---------------------------------------------------------------------------
 
 template <>
-inline  mpz_class int_max_value_dual<mpz_class>() {
+inline mpz_class int_max_value_dual<mpz_class>() {
     assert(false);
     return 0;
 }
@@ -837,7 +709,7 @@ Integer int_max_value_primary() {
 // bool int_max_value_primary_long_computed = false;
 
 template <>
-inline  long int_max_value_primary() {
+inline long int_max_value_primary() {
     static long max_value;
 
     if (int_max_value_primary_long_computed)
@@ -855,7 +727,7 @@ inline  long int_max_value_primary() {
 // bool int_max_value_primary_long_long_computed = false;
 
 template <>
-inline  long long int_max_value_primary() {
+inline long long int_max_value_primary() {
     static long long max_value;
 
     if (int_max_value_primary_long_long_computed)
@@ -865,8 +737,8 @@ inline  long long int_max_value_primary() {
     long long test = 1;
     test = test << k;  // 2^k
 #ifdef NMZ_EXTENDED_TESTS
-    if(test_linear_algebra_GMP)
-        test=0;
+    if (test_linear_algebra_GMP)
+        test = 0;
 #endif
     max_value = test;
     int_max_value_primary_long_long_computed = true;
@@ -876,14 +748,14 @@ inline  long long int_max_value_primary() {
 //---------------------------------------------------------------------------
 
 template <>
-inline  mpz_class int_max_value_primary<mpz_class>() {
+inline mpz_class int_max_value_primary<mpz_class>() {
     assert(false);
     return 0;
 }
 
 #ifdef ENFNORMALIZ
 template <>
-inline  renf_elem_class int_max_value_primary<renf_elem_class>() {
+inline renf_elem_class int_max_value_primary<renf_elem_class>() {
     assert(false);
     return 0;
 }
@@ -918,7 +790,7 @@ void check_range_list(const std::list<Candidate<Integer> >& ll) {
 
 //---------------------------------------------------------------------------
 
-inline  mpq_class dec_fraction_to_mpq(string s) {
+inline mpq_class dec_fraction_to_mpq(string s) {
     size_t skip = 0;  // skip leading spaces
     for (; skip < s.size(); ++skip) {
         if (!isspace(s[skip]))
@@ -970,13 +842,13 @@ inline  mpq_class dec_fraction_to_mpq(string s) {
         frac_string = frac_string.substr(1);
     if (exp_string.size() > 0 && exp_string[0] == '+')
         exp_string = exp_string.substr(1);
-    bool exponent_could_be_zero=false;
-    while (exp_string.size() > 0 && exp_string[0] == '0'){
+    bool exponent_could_be_zero = false;
+    while (exp_string.size() > 0 && exp_string[0] == '0') {
         exponent_could_be_zero = true;
         exp_string = exp_string.substr(1);
     }
-    
-    if(pos_E != string::npos &&  exp_string == "" && !exponent_could_be_zero)
+
+    if (pos_E != string::npos && exp_string == "" && !exponent_could_be_zero)
         throw BadInputException("No exponent following character e in floating point number");
 
     mpq_class int_part, frac_part, exp_part;
@@ -1048,7 +920,6 @@ inline bool int_quotient(IntegerRet& Quot, const nmz_float& Num, const nmz_float
     return FloatQuot - IntQuot > nmz_epsilon;
 }
 
-
 template <typename IntegerRet, typename IntegerVal>
 IntegerRet floor_quot(const IntegerVal Num, IntegerVal Den) {
     IntegerRet Quot;
@@ -1110,7 +981,7 @@ inline mpz_class ceil(const mpq_class& q) {
     return ent;
 }
 
-inline  mpz_class round(const mpq_class& q) {
+inline mpz_class round(const mpq_class& q) {
     mpq_class work;
     if (q >= 0) {
         work = q - mpq_class(1, 2);
@@ -1130,7 +1001,6 @@ mpz_class nmz_factorial(Integer n) {
     return f;
 }
 
-
 template <typename Integer>
 mpz_class nmz_binomial(Integer n, Integer k) {
     if (k > n)
@@ -1138,8 +1008,7 @@ mpz_class nmz_binomial(Integer n, Integer k) {
     return nmz_factorial(n) / nmz_factorial(k);
 }
 
-
-inline  nmz_float mpq_to_nmz_float(const mpq_class& val) {
+inline nmz_float mpq_to_nmz_float(const mpq_class& val) {
     mpz_class bound = 1;
     for (size_t i = 0; i < 60; ++i)
         bound *= 10;
@@ -1155,33 +1024,27 @@ inline  nmz_float mpq_to_nmz_float(const mpq_class& val) {
 }
 
 template <typename Integer>
-long convertToLong(const Integer& val){
-
+long convertToLong(const Integer& val) {
     long ret;
-    try{
+    try {
         ret = convertTo<long>(val);
-    }
-    catch (const ArithmeticException& e){
+    } catch (const ArithmeticException& e) {
         throw LongException(val);
     }
-    
-    return ret;    
-    
+
+    return ret;
 }
 
 template <typename Integer>
-long convertToLongLong(const Integer& val){
-
+long convertToLongLong(const Integer& val) {
     long ret;
-    try{
+    try {
         ret = convertTo<long long>(val);
-    }
-    catch (const ArithmeticException& e){
+    } catch (const ArithmeticException& e) {
         throw LongLongException(val);
     }
-    
-    return ret;    
-    
+
+    return ret;
 }
 }  // namespace libnormaliz
 
